@@ -8,7 +8,6 @@ from . import _omplpy
 
 VectorLike = Union[np.ndarray, Sequence[float]]
 IsValidFunc = Callable[[List[float]], bool]
-PathLike = Union[Path, str]
 
 
 class Algorithm(Enum):
@@ -44,7 +43,7 @@ def set_ompl_random_seed(seed: int) -> None:
 class _OMPLPlannerBase(ABC):
     """
     An additional higher layer wrapper.
-    One important reason of this class is exposing type hinting
+    The primal reason of this class is exposing type hinting
     """
     _planner: Any
     _is_valid: IsValidFunc
@@ -92,41 +91,83 @@ class _OMPLPlannerBase(ABC):
 
 
 class Planner(_OMPLPlannerBase):
-    """
-    An additional higher layer wrapper.
-    One important reason of this class is exposing type hinting
-    """
+
+    def __init__(self,
+            lb: VectorLike,
+            ub: VectorLike,
+            is_valid: IsValidFunc,
+            n_max_is_valid: int,
+            validation_box: Union[np.ndarray, float],
+            algo: Algorithm = Algorithm.RRTConnect):
+
+        lb = np.array(lb)
+        ub = np.array(ub)
+        assert lb.ndim == 1
+        assert ub.ndim == 1
+        assert len(lb) == len(ub)
+        planner_t = self.planner_type()
+        if isinstance(validation_box, float):
+            dim = len(lb)
+            validation_box = np.array([validation_box] * dim)
+        self._planner = planner_t(lb, ub, is_valid, n_max_is_valid, validation_box, algo.value)
+        self.reset_is_valid(is_valid)
+
     def planner_type(self) -> Any:
         return _omplpy._OMPLPlanner
 
 
-class LightningPlanner(_OMPLPlannerBase):
+class LightningDB(_omplpy._LightningDB):
+    dim: int
 
-    def planner_type(self) -> Any:
-        return _omplpy._LightningPlanner
+    def __init__(self, dim: int):
+        self.dim = dim
+        super().__init__(dim)
 
-    def scratch(self) -> None:
-        self._planner.scratch()
+    def add_experience(self, experience: List[np.ndarray]) -> None:
+        assert experience[0].shape == (self.dim,)
+        super().add_experience(np.array(experience).tolist())
 
-    def recall(self) -> None:
-        self._planner.recall()
+    def get_experienced_paths(self) -> List[np.ndarray]:
+        paths = super().get_experienced_paths()
+        return [np.array(p) for p in paths]
 
-    def dump(self, path: PathLike) -> None:
+    def get_experiences_count(self) -> int:
+        return super().get_experiences_count()
+
+    def save(self, path: Union[Path, str]) -> None:
         if isinstance(path, Path):
             path = str(path.expanduser())
         self._planner.dump(path)
 
-    def load(self, path: PathLike) -> None:
+    @classmethod
+    def load(self, path: Union[Path, str]) -> None:
         if isinstance(path, Path):
             path = str(path.expanduser())
         self._planner.load(path)
 
-    def get_experienced_paths(self) -> List[np.ndarray]:
-        paths = self._planner.get_experienced_paths()
-        return paths
 
-    def get_latest_activated_index(self) -> int:
-        return self._planner.get_latest_activated_index()
+class LightningPlanner(_OMPLPlannerBase):
 
-    def get_experiences_count(self) -> int:
-        return self._planner.get_experiences_count()
+    def __init__(self,
+            db: LightningDB,
+            lb: VectorLike,
+            ub: VectorLike,
+            is_valid: IsValidFunc,
+            n_max_is_valid: int,
+            validation_box: Union[np.ndarray, float],
+            algo: Algorithm = Algorithm.RRTConnect):
+
+        lb = np.array(lb)
+        ub = np.array(ub)
+        assert lb.ndim == 1
+        assert ub.ndim == 1
+        assert len(lb) == len(ub)
+        planner_t = self.planner_type()
+        if isinstance(validation_box, float):
+            dim = len(lb)
+            validation_box = np.array([validation_box] * dim)
+        self._planner = planner_t(db, lb, ub, is_valid, n_max_is_valid, validation_box, algo.value)
+        self.reset_is_valid(is_valid)
+
+    def planner_type(self) -> Any:
+        return _omplpy._LightningPlanner
